@@ -15,7 +15,7 @@ use Catalyst::Runtime 5.80;
 
 use Catalyst qw/
     Static::Simple
-    Unicode
+    Unicode::Encoding
 /;
 
 extends 'Catalyst';
@@ -23,6 +23,7 @@ extends 'Catalyst';
 __PACKAGE__->config(
     name => 'MyApp',
     disable_component_resolution_regex_fallback => 1,
+    encoding => 'UTF-8'
 );
 
 __PACKAGE__->setup();
